@@ -2,18 +2,26 @@
 
 namespace Wallabag\CoreBundle\Controller;
 
+use Craue\ConfigBundle\Util\Config;
+use Doctrine\DBAL\Platforms\SqlitePlatform;
+use Doctrine\ORM\EntityManagerInterface;
+use FOS\UserBundle\Model\UserManagerInterface;
 use JMS\Serializer\SerializationContext;
 use JMS\Serializer\SerializerBuilder;
 use PragmaRX\Recovery\Recovery as BackupCodes;
-use Symfony\Bundle\FrameworkBundle\Controller\Controller;
+use Scheb\TwoFactorBundle\Security\TwoFactor\Provider\Google\GoogleAuthenticatorInterface;
+use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
 use Symfony\Component\HttpFoundation\JsonResponse;
 use Symfony\Component\HttpFoundation\RedirectResponse;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
 use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;
 use Symfony\Component\Validator\Constraints\Locale as LocaleConstraint;
-use Wallabag\CoreBundle\Entity\Config;
+use Symfony\Component\Validator\Validator\ValidatorInterface;
+use Wallabag\AnnotationBundle\Repository\AnnotationRepository;
+use Wallabag\CoreBundle\Entity\Config as ConfigEntity;
 use Wallabag\CoreBundle\Entity\IgnoreOriginUserRule;
 use Wallabag\CoreBundle\Entity\RuleInterface;
 use Wallabag\CoreBundle\Entity\TaggingRule;
@@ -24,18 +32,39 @@ use Wallabag\CoreBundle\Form\Type\IgnoreOriginUserRuleType;
 use Wallabag\CoreBundle\Form\Type\TaggingRuleImportType;
 use Wallabag\CoreBundle\Form\Type\TaggingRuleType;
 use Wallabag\CoreBundle\Form\Type\UserInformationType;
+use Wallabag\CoreBundle\Repository\ConfigRepository;
+use Wallabag\CoreBundle\Repository\EntryRepository;
+use Wallabag\CoreBundle\Repository\IgnoreOriginUserRuleRepository;
+use Wallabag\CoreBundle\Repository\TaggingRuleRepository;
+use Wallabag\CoreBundle\Repository\TagRepository;
 use Wallabag\CoreBundle\Tools\Utils;
+use Wallabag\UserBundle\Repository\UserRepository;
 
-class ConfigController extends Controller
+class ConfigController extends AbstractController
 {
+    private EntityManagerInterface $entityManager;
+    private UserManagerInterface $userManager;
+    private EntryRepository $entryRepository;
+    private TagRepository $tagRepository;
+    private AnnotationRepository $annotationRepository;
+    private ConfigRepository $configRepository;
+
+    public function __construct(EntityManagerInterface $entityManager, UserManagerInterface $userManager, EntryRepository $entryRepository, TagRepository $tagRepository, AnnotationRepository $annotationRepository, ConfigRepository $configRepository)
+    {
+        $this->entityManager = $entityManager;
+        $this->userManager = $userManager;
+        $this->entryRepository = $entryRepository;
+        $this->tagRepository = $tagRepository;
+        $this->annotationRepository = $annotationRepository;
+        $this->configRepository = $configRepository;
+    }
+
     /**
      * @Route("/config", name="config")
      */
-    public function indexAction(Request $request)
+    public function indexAction(Request $request, Config $craueConfig, TaggingRuleRepository $taggingRuleRepository, IgnoreOriginUserRuleRepository $ignoreOriginUserRuleRepository, UserRepository $userRepository)
     {
-        $em = $this->getDoctrine()->getManager();
         $config = $this->getConfig();
-        $userManager = $this->container->get('fos_user.user_manager');
         $user = $this->getUser();
 
         // handle basic config detail (this form is defined as a service)
@@ -43,25 +72,11 @@ class ConfigController extends Controller
         $configForm->handleRequest($request);
 
         if ($configForm->isSubmitted() && $configForm->isValid()) {
-            // force theme to material to avoid using baggy
-            if ('baggy' === $config->getTheme()) {
-                $config->setTheme('material');
-
-                $this->addFlash(
-                    'notice',
-                    'Baggy is deprecated, forced to Material theme.'
-                );
-            }
-
-            $em->persist($config);
-            $em->flush();
+            $this->entityManager->persist($config);
+            $this->entityManager->flush();
 
             $request->getSession()->set('_locale', $config->getLanguage());
 
-            // switch active theme
-            $activeTheme = $this->get('liip_theme.active_theme');
-            $activeTheme->setName($config->getTheme());
-
             $this->addFlash(
                 'notice',
                 'flashes.config.notice.config_saved'
@@ -75,13 +90,13 @@ class ConfigController extends Controller
         $pwdForm->handleRequest($request);
 
         if ($pwdForm->isSubmitted() && $pwdForm->isValid()) {
-            if ($this->get('craue_config')->get('demo_mode_enabled') && $this->get('craue_config')->get('demo_mode_username') === $user->getUsername()) {
+            if ($craueConfig->get('demo_mode_enabled') && $craueConfig->get('demo_mode_username') === $user->getUsername()) {
                 $message = 'flashes.config.notice.password_not_updated_demo';
             } else {
                 $message = 'flashes.config.notice.password_updated';
 
                 $user->setPlainPassword($pwdForm->get('new_password')->getData());
-                $userManager->updateUser($user, true);
+                $this->userManager->updateUser($user, true);
             }
 
             $this->addFlash('notice', $message);
@@ -97,7 +112,7 @@ class ConfigController extends Controller
         $userForm->handleRequest($request);
 
         if ($userForm->isSubmitted() && $userForm->isValid()) {
-            $userManager->updateUser($user, true);
+            $this->userManager->updateUser($user, true);
 
             $this->addFlash(
                 'notice',
@@ -112,8 +127,8 @@ class ConfigController extends Controller
         $feedForm->handleRequest($request);
 
         if ($feedForm->isSubmitted() && $feedForm->isValid()) {
-            $em->persist($config);
-            $em->flush();
+            $this->entityManager->persist($config);
+            $this->entityManager->flush();
 
             $this->addFlash(
                 'notice',
@@ -128,9 +143,7 @@ class ConfigController extends Controller
         $action = $this->generateUrl('config') . '#set5';
 
         if ($request->query->has('tagging-rule')) {
-            $taggingRule = $this->getDoctrine()
-                ->getRepository('WallabagCoreBundle:TaggingRule')
-                ->find($request->query->get('tagging-rule'));
+            $taggingRule = $taggingRuleRepository->find($request->query->get('tagging-rule'));
 
             if ($this->getUser()->getId() !== $taggingRule->getConfig()->getUser()->getId()) {
                 return $this->redirect($action);
@@ -144,8 +157,8 @@ class ConfigController extends Controller
 
         if ($newTaggingRule->isSubmitted() && $newTaggingRule->isValid()) {
             $taggingRule->setConfig($config);
-            $em->persist($taggingRule);
-            $em->flush();
+            $this->entityManager->persist($taggingRule);
+            $this->entityManager->flush();
 
             $this->addFlash(
                 'notice',
@@ -172,10 +185,10 @@ class ConfigController extends Controller
                         $taggingRule->setRule($rule['rule']);
                         $taggingRule->setTags($rule['tags']);
                         $taggingRule->setConfig($config);
-                        $em->persist($taggingRule);
+                        $this->entityManager->persist($taggingRule);
                     }
 
-                    $em->flush();
+                    $this->entityManager->flush();
 
                     $message = 'flashes.config.notice.tagging_rules_imported';
                 }
@@ -191,8 +204,7 @@ class ConfigController extends Controller
         $action = $this->generateUrl('config') . '#set6';
 
         if ($request->query->has('ignore-origin-user-rule')) {
-            $ignoreOriginUserRule = $this->getDoctrine()
-                ->getRepository('WallabagCoreBundle:IgnoreOriginUserRule')
+            $ignoreOriginUserRule = $ignoreOriginUserRuleRepository
                 ->find($request->query->get('ignore-origin-user-rule'));
 
             if ($this->getUser()->getId() !== $ignoreOriginUserRule->getConfig()->getUser()->getId()) {
@@ -209,8 +221,8 @@ class ConfigController extends Controller
 
         if ($newIgnoreOriginUserRule->isSubmitted() && $newIgnoreOriginUserRule->isValid()) {
             $ignoreOriginUserRule->setConfig($config);
-            $em->persist($ignoreOriginUserRule);
-            $em->flush();
+            $this->entityManager->persist($ignoreOriginUserRule);
+            $this->entityManager->flush();
 
             $this->addFlash(
                 'notice',
@@ -220,7 +232,7 @@ class ConfigController extends Controller
             return $this->redirect($this->generateUrl('config') . '#set6');
         }
 
-        return $this->render('WallabagCoreBundle:Config:index.html.twig', [
+        return $this->render('@WallabagCore/Config/index.html.twig', [
             'form' => [
                 'config' => $configForm->createView(),
                 'feed' => $feedForm->createView(),
@@ -236,7 +248,7 @@ class ConfigController extends Controller
             ],
             'twofactor_auth' => $this->getParameter('twofactor_auth'),
             'wallabag_url' => $this->getParameter('domain_name'),
-            'enabled_users' => $this->get('wallabag_user.user_repository')->getSumEnabledUsers(),
+            'enabled_users' => $userRepository->getSumEnabledUsers(),
         ]);
     }
 
@@ -254,7 +266,7 @@ class ConfigController extends Controller
         $user = $this->getUser();
         $user->setEmailTwoFactor(false);
 
-        $this->container->get('fos_user.user_manager')->updateUser($user, true);
+        $this->userManager->updateUser($user, true);
 
         $this->addFlash(
             'notice',
@@ -281,7 +293,7 @@ class ConfigController extends Controller
         $user->setBackupCodes(null);
         $user->setEmailTwoFactor(true);
 
-        $this->container->get('fos_user.user_manager')->updateUser($user, true);
+        $this->userManager->updateUser($user, true);
 
         $this->addFlash(
             'notice',
@@ -307,7 +319,7 @@ class ConfigController extends Controller
         $user->setGoogleAuthenticatorSecret('');
         $user->setBackupCodes(null);
 
-        $this->container->get('fos_user.user_manager')->updateUser($user, true);
+        $this->userManager->updateUser($user, true);
 
         $this->addFlash(
             'notice',
@@ -322,14 +334,14 @@ class ConfigController extends Controller
      *
      * @Route("/config/otp/app", name="config_otp_app")
      */
-    public function otpAppAction()
+    public function otpAppAction(GoogleAuthenticatorInterface $googleAuthenticator)
     {
         if (!$this->getParameter('twofactor_auth')) {
             return $this->createNotFoundException('two_factor not enabled');
         }
 
         $user = $this->getUser();
-        $secret = $this->get('scheb_two_factor.security.google_authenticator')->generateSecret();
+        $secret = $googleAuthenticator->generateSecret();
 
         $user->setGoogleAuthenticatorSecret($secret);
         $user->setEmailTwoFactor(false);
@@ -344,16 +356,16 @@ class ConfigController extends Controller
 
         $user->setBackupCodes($backupCodesHashed);
 
-        $this->container->get('fos_user.user_manager')->updateUser($user, true);
+        $this->userManager->updateUser($user, true);
 
         $this->addFlash(
             'notice',
             'flashes.config.notice.otp_enabled'
         );
 
-        return $this->render('WallabagCoreBundle:Config:otp_app.html.twig', [
+        return $this->render('@WallabagCore/Config/otp_app.html.twig', [
             'backupCodes' => $backupCodes,
-            'qr_code' => $this->get('scheb_two_factor.security.google_authenticator')->getQRContent($user),
+            'qr_code' => $googleAuthenticator->getQRContent($user),
             'secret' => $secret,
         ]);
     }
@@ -373,7 +385,7 @@ class ConfigController extends Controller
         $user->setGoogleAuthenticatorSecret(null);
         $user->setBackupCodes(null);
 
-        $this->container->get('fos_user.user_manager')->updateUser($user, true);
+        $this->userManager->updateUser($user, true);
 
         return $this->redirect($this->generateUrl('config') . '#set3');
     }
@@ -383,9 +395,9 @@ class ConfigController extends Controller
      *
      * @Route("/config/otp/app/check", name="config_otp_app_check")
      */
-    public function otpAppCheckAction(Request $request)
+    public function otpAppCheckAction(Request $request, GoogleAuthenticatorInterface $googleAuthenticator)
     {
-        $isValid = $this->get('scheb_two_factor.security.google_authenticator')->checkCode(
+        $isValid = $googleAuthenticator->checkCode(
             $this->getUser(),
             $request->get('_auth_code')
         );
@@ -417,9 +429,8 @@ class ConfigController extends Controller
         $config = $this->getConfig();
         $config->setFeedToken(Utils::generateToken());
 
-        $em = $this->getDoctrine()->getManager();
-        $em->persist($config);
-        $em->flush();
+        $this->entityManager->persist($config);
+        $this->entityManager->flush();
 
         if ($request->isXmlHttpRequest()) {
             return new JsonResponse(['token' => $config->getFeedToken()]);
@@ -443,9 +454,8 @@ class ConfigController extends Controller
         $config = $this->getConfig();
         $config->setFeedToken(null);
 
-        $em = $this->getDoctrine()->getManager();
-        $em->persist($config);
-        $em->flush();
+        $this->entityManager->persist($config);
+        $this->entityManager->flush();
 
         if ($request->isXmlHttpRequest()) {
             return new JsonResponse();
@@ -470,9 +480,8 @@ class ConfigController extends Controller
     {
         $this->validateRuleAction($rule);
 
-        $em = $this->getDoctrine()->getManager();
-        $em->remove($rule);
-        $em->flush();
+        $this->entityManager->remove($rule);
+        $this->entityManager->flush();
 
         $this->addFlash(
             'notice',
@@ -507,9 +516,8 @@ class ConfigController extends Controller
     {
         $this->validateRuleAction($rule);
 
-        $em = $this->getDoctrine()->getManager();
-        $em->remove($rule);
-        $em->flush();
+        $this->entityManager->remove($rule);
+        $this->entityManager->flush();
 
         $this->addFlash(
             'notice',
@@ -540,13 +548,11 @@ class ConfigController extends Controller
      *
      * @return RedirectResponse
      */
-    public function resetAction($type)
+    public function resetAction(string $type, AnnotationRepository $annotationRepository, EntryRepository $entryRepository)
     {
         switch ($type) {
             case 'annotations':
-                $this->getDoctrine()
-                    ->getRepository('WallabagAnnotationBundle:Annotation')
-                    ->removeAllByUserId($this->getUser()->getId());
+                $annotationRepository->removeAllByUserId($this->getUser()->getId());
                 break;
             case 'tags':
                 $this->removeAllTagsByUserId($this->getUser()->getId());
@@ -554,24 +560,24 @@ class ConfigController extends Controller
             case 'entries':
                 // SQLite doesn't care about cascading remove, so we need to manually remove associated stuff
                 // otherwise they won't be removed ...
-                if ($this->get('doctrine')->getConnection()->getDatabasePlatform() instanceof \Doctrine\DBAL\Platforms\SqlitePlatform) {
-                    $this->getDoctrine()->getRepository('WallabagAnnotationBundle:Annotation')->removeAllByUserId($this->getUser()->getId());
+                if ($this->entityManager->getConnection()->getDatabasePlatform() instanceof SqlitePlatform) {
+                    $annotationRepository->removeAllByUserId($this->getUser()->getId());
                 }
 
                 // manually remove tags to avoid orphan tag
                 $this->removeAllTagsByUserId($this->getUser()->getId());
 
-                $this->get('wallabag_core.entry_repository')->removeAllByUserId($this->getUser()->getId());
+                $entryRepository->removeAllByUserId($this->getUser()->getId());
                 break;
             case 'archived':
-                if ($this->get('doctrine')->getConnection()->getDatabasePlatform() instanceof \Doctrine\DBAL\Platforms\SqlitePlatform) {
+                if ($this->entityManager->getConnection()->getDatabasePlatform() instanceof SqlitePlatform) {
                     $this->removeAnnotationsForArchivedByUserId($this->getUser()->getId());
                 }
 
                 // manually remove tags to avoid orphan tag
                 $this->removeTagsForArchivedByUserId($this->getUser()->getId());
 
-                $this->get('wallabag_core.entry_repository')->removeArchivedByUserId($this->getUser()->getId());
+                $entryRepository->removeArchivedByUserId($this->getUser()->getId());
                 break;
         }
 
@@ -590,16 +596,15 @@ class ConfigController extends Controller
      *
      * @throws AccessDeniedHttpException
      *
-     * @return \Symfony\Component\HttpFoundation\RedirectResponse
+     * @return RedirectResponse
      */
-    public function deleteAccountAction(Request $request)
+    public function deleteAccountAction(Request $request, UserRepository $userRepository, TokenStorageInterface $tokenStorage)
     {
         if (!$this->isCsrfTokenValid('delete-account', $request->request->get('token'))) {
             throw $this->createAccessDeniedException('Bad CSRF token.');
         }
 
-        $enabledUsers = $this->get('wallabag_user.user_repository')
-            ->getSumEnabledUsers();
+        $enabledUsers = $userRepository->getSumEnabledUsers();
 
         if ($enabledUsers <= 1) {
             throw new AccessDeniedHttpException();
@@ -608,11 +613,10 @@ class ConfigController extends Controller
         $user = $this->getUser();
 
         // logout current user
-        $this->get('security.token_storage')->setToken(null);
+        $tokenStorage->setToken(null);
         $request->getSession()->invalidate();
 
-        $em = $this->get('fos_user.user_manager');
-        $em->deleteUser($user);
+        $this->userManager->deleteUser($user);
 
         return $this->redirect($this->generateUrl('fos_user_security_login'));
     }
@@ -622,16 +626,15 @@ class ConfigController extends Controller
      *
      * @Route("/config/view-mode", name="switch_view_mode")
      *
-     * @return \Symfony\Component\HttpFoundation\RedirectResponse
+     * @return RedirectResponse
      */
     public function changeViewModeAction(Request $request)
     {
         $user = $this->getUser();
         $user->getConfig()->setListMode(!$user->getConfig()->getListMode());
 
-        $em = $this->getDoctrine()->getManager();
-        $em->persist($user);
-        $em->flush();
+        $this->entityManager->persist($user);
+        $this->entityManager->flush();
 
         return $this->redirect($request->headers->get('referer'));
     }
@@ -643,11 +646,11 @@ class ConfigController extends Controller
      *
      * @Route("/locale/{language}", name="changeLocale")
      *
-     * @return \Symfony\Component\HttpFoundation\RedirectResponse
+     * @return RedirectResponse
      */
-    public function setLocaleAction(Request $request, $language = null)
+    public function setLocaleAction(Request $request, ValidatorInterface $validator, $language = null)
     {
-        $errors = $this->get('validator')->validate($language, (new LocaleConstraint()));
+        $errors = $validator->validate($language, (new LocaleConstraint()));
 
         if (0 === \count($errors)) {
             $request->getSession()->set('_locale', $language);
@@ -694,19 +697,16 @@ class ConfigController extends Controller
             return;
         }
 
-        $this->get('wallabag_core.entry_repository')
-            ->removeTags($userId, $tags);
+        $this->entryRepository->removeTags($userId, $tags);
 
         // cleanup orphan tags
-        $em = $this->getDoctrine()->getManager();
-
         foreach ($tags as $tag) {
             if (0 === \count($tag->getEntries())) {
-                $em->remove($tag);
+                $this->entityManager->remove($tag);
             }
         }
 
-        $em->flush();
+        $this->entityManager->flush();
     }
 
     /**
@@ -716,7 +716,7 @@ class ConfigController extends Controller
      */
     private function removeAllTagsByUserId($userId)
     {
-        $tags = $this->get('wallabag_core.tag_repository')->findAllTags($userId);
+        $tags = $this->tagRepository->findAllTags($userId);
         $this->removeAllTagsByStatusAndUserId($tags, $userId);
     }
 
@@ -727,23 +727,20 @@ class ConfigController extends Controller
      */
     private function removeTagsForArchivedByUserId($userId)
     {
-        $tags = $this->get('wallabag_core.tag_repository')->findForArchivedArticlesByUser($userId);
+        $tags = $this->tagRepository->findForArchivedArticlesByUser($userId);
         $this->removeAllTagsByStatusAndUserId($tags, $userId);
     }
 
     private function removeAnnotationsForArchivedByUserId($userId)
     {
-        $em = $this->getDoctrine()->getManager();
-
-        $archivedEntriesAnnotations = $this->getDoctrine()
-            ->getRepository('WallabagAnnotationBundle:Annotation')
+        $archivedEntriesAnnotations = $this->annotationRepository
             ->findAllArchivedEntriesByUser($userId);
 
         foreach ($archivedEntriesAnnotations as $archivedEntriesAnnotation) {
-            $em->remove($archivedEntriesAnnotation);
+            $this->entityManager->remove($archivedEntriesAnnotation);
         }
 
-        $em->flush();
+        $this->entityManager->flush();
     }
 
     /**
@@ -760,17 +757,15 @@ class ConfigController extends Controller
      * Retrieve config for the current user.
      * If no config were found, create a new one.
      *
-     * @return Config
+     * @return ConfigEntity
      */
     private function getConfig()
     {
-        $config = $this->getDoctrine()
-            ->getRepository('WallabagCoreBundle:Config')
-            ->findOneByUser($this->getUser());
+        $config = $this->configRepository->findOneByUser($this->getUser());
 
         // should NEVER HAPPEN ...
         if (!$config) {
-            $config = new Config($this->getUser());
+            $config = new ConfigEntity($this->getUser());
         }
 
         return $config;
