@@ -2,19 +2,25 @@
 
 namespace Tests\Wallabag\CoreBundle\Controller;
 
+use Craue\ConfigBundle\Util\Config;
+use Doctrine\ORM\EntityManagerInterface;
 use Symfony\Component\HttpFoundation\File\UploadedFile;
+use Symfony\Component\HttpFoundation\Session\SessionInterface;
+use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;
 use Tests\Wallabag\CoreBundle\WallabagCoreTestCase;
 use Wallabag\AnnotationBundle\Entity\Annotation;
-use Wallabag\CoreBundle\Entity\Config;
+use Wallabag\CoreBundle\Entity\Config as ConfigEntity;
 use Wallabag\CoreBundle\Entity\Entry;
+use Wallabag\CoreBundle\Entity\IgnoreOriginUserRule;
 use Wallabag\CoreBundle\Entity\Tag;
+use Wallabag\CoreBundle\Entity\TaggingRule;
 use Wallabag\UserBundle\Entity\User;
 
 class ConfigControllerTest extends WallabagCoreTestCase
 {
     public function testLogin()
     {
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $client->request('GET', '/new');
 
@@ -25,7 +31,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testIndex()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -40,7 +46,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testUpdate()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -49,7 +55,6 @@ class ConfigControllerTest extends WallabagCoreTestCase
         $form = $crawler->filter('button[id=config_save]')->form();
 
         $data = [
-            'config[theme]' => 'baggy',
             'config[items_per_page]' => '30',
             'config[reading_speed]' => '100',
             'config[action_mark_as_read]' => '0',
@@ -68,8 +73,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testChangeReadingSpeed()
     {
         $this->logInAs('admin');
-        $this->useTheme('baggy');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $entry = new Entry($this->getLoggedInUser());
         $entry->setUrl('http://0.0.0.0/test-entry1')
@@ -86,7 +90,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
             'entry_filter[readingTime][left_number]' => 22,
         ];
         $crawler = $client->submit($form, $dataFilters);
-        $this->assertCount(1, $crawler->filter('div[class=entry]'));
+        $this->assertCount(0, $crawler->filter('div[class=entry]'));
 
         // Change reading speed
         $crawler = $client->request('GET', '/config');
@@ -115,7 +119,6 @@ class ConfigControllerTest extends WallabagCoreTestCase
     {
         return [
             [[
-                'config[theme]' => 'baggy',
                 'config[items_per_page]' => '',
                 'config[language]' => 'en',
             ]],
@@ -128,7 +131,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testUpdateFailed($data)
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -188,7 +191,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testChangePasswordFailed($data, $expectedMessage)
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -207,7 +210,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testChangePassword()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -256,7 +259,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testUserFailed($data, $expectedMessage)
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -275,7 +278,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testUserUpdate()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -301,12 +304,12 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testFeedUpdateResetToken()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         // reset the token
-        $em = $client->getContainer()->get('doctrine.orm.entity_manager');
+        $em = $client->getContainer()->get(EntityManagerInterface::class);
         $user = $em
-            ->getRepository('WallabagUserBundle:User')
+            ->getRepository(User::class)
             ->findOneByUsername('admin');
 
         if (!$user) {
@@ -337,7 +340,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testGenerateTokenAjax()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $client->request(
             'GET',
@@ -355,7 +358,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testRevokeTokenAjax()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $client->request(
             'GET',
@@ -371,7 +374,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testFeedUpdate()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -399,7 +402,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
                 [
                     'feed_config[feed_limit]' => 0,
                 ],
-                'This value should be 1 or more.',
+                'This value should be between 1 and 100000.',
             ],
             [
                 [
@@ -416,7 +419,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testFeedFailed($data, $expectedMessage)
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -435,7 +438,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testTaggingRuleCreation()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -456,7 +459,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
 
         $this->assertStringContainsString('flashes.config.notice.tagging_rules_updated', $crawler->filter('body')->extract(['_text'])[0]);
 
-        $editLink = $crawler->filter('div[id=set5] a.mode_edit')->last()->link();
+        $editLink = $crawler->filter('.mode_edit_tagging_rule')->last()->link();
 
         $crawler = $client->click($editLink);
         $this->assertSame(302, $client->getResponse()->getStatusCode());
@@ -481,7 +484,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
 
         $this->assertStringContainsString('readingTime <= 30', $crawler->filter('body')->extract(['_text'])[0]);
 
-        $deleteLink = $crawler->filter('div[id=set5] a.delete')->last()->link();
+        $deleteLink = $crawler->filter('.delete_tagging_rule')->last()->link();
 
         $crawler = $client->click($deleteLink);
         $this->assertSame(302, $client->getResponse()->getStatusCode());
@@ -522,7 +525,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testTaggingRuleCreationFail($data, $messages)
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -544,7 +547,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testTaggingRuleTooLong()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -567,10 +570,10 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testDeletingTaggingRuleFromAnOtherUser()
     {
         $this->logInAs('bob');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
-        $rule = $client->getContainer()->get('doctrine.orm.entity_manager')
-            ->getRepository('WallabagCoreBundle:TaggingRule')
+        $rule = $client->getContainer()->get(EntityManagerInterface::class)
+            ->getRepository(TaggingRule::class)
             ->findAll()[0];
 
         $crawler = $client->request('GET', '/tagging-rule/delete/' . $rule->getId());
@@ -583,10 +586,10 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testEditingTaggingRuleFromAnOtherUser()
     {
         $this->logInAs('bob');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
-        $rule = $client->getContainer()->get('doctrine.orm.entity_manager')
-            ->getRepository('WallabagCoreBundle:TaggingRule')
+        $rule = $client->getContainer()->get(EntityManagerInterface::class)
+            ->getRepository(TaggingRule::class)
             ->findAll()[0];
 
         $crawler = $client->request('GET', '/tagging-rule/edit/' . $rule->getId());
@@ -599,7 +602,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testIgnoreOriginRuleCreation()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -682,7 +685,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testIgnoreOriginRuleCreationFail($data, $messages)
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
@@ -704,10 +707,10 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testDeletingIgnoreOriginRuleFromAnOtherUser()
     {
         $this->logInAs('bob');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
-        $rule = $client->getContainer()->get('doctrine.orm.entity_manager')
-            ->getRepository('WallabagCoreBundle:IgnoreOriginUserRule')
+        $rule = $client->getContainer()->get(EntityManagerInterface::class)
+            ->getRepository(IgnoreOriginUserRule::class)
             ->findAll()[0];
 
         $crawler = $client->request('GET', '/ignore-origin-user-rule/edit/' . $rule->getId());
@@ -720,10 +723,10 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testEditingIgnoreOriginRuleFromAnOtherUser()
     {
         $this->logInAs('bob');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
-        $rule = $client->getContainer()->get('doctrine.orm.entity_manager')
-            ->getRepository('WallabagCoreBundle:IgnoreOriginUserRule')
+        $rule = $client->getContainer()->get(EntityManagerInterface::class)
+            ->getRepository(IgnoreOriginUserRule::class)
             ->findAll()[0];
 
         $crawler = $client->request('GET', '/ignore-origin-user-rule/edit/' . $rule->getId());
@@ -736,9 +739,9 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testDemoMode()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
-        $config = $client->getContainer()->get('craue_config');
+        $config = $client->getContainer()->get(Config::class);
         $config->set('demo_mode_enabled', 1);
         $config->set('demo_mode_username', 'admin');
 
@@ -757,7 +760,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
         $client->submit($form, $data);
 
         $this->assertSame(302, $client->getResponse()->getStatusCode());
-        $this->assertStringContainsString('flashes.config.notice.password_not_updated_demo', $client->getContainer()->get('session')->getFlashBag()->get('notice')[0]);
+        $this->assertStringContainsString('flashes.config.notice.password_not_updated_demo', $client->getContainer()->get(SessionInterface::class)->getFlashBag()->get('notice')[0]);
 
         $config->set('demo_mode_enabled', 0);
         $config->set('demo_mode_username', 'wallabag');
@@ -766,23 +769,23 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testDeleteUserButtonVisibility()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
 
         $this->assertGreaterThan(1, $body = $crawler->filter('body')->extract(['_text']));
         $this->assertStringContainsString('config.form_user.delete.button', $body[0]);
 
-        $em = $client->getContainer()->get('doctrine.orm.entity_manager');
+        $em = $client->getContainer()->get(EntityManagerInterface::class);
 
         $user = $em
-            ->getRepository('WallabagUserBundle:User')
+            ->getRepository(User::class)
             ->findOneByUsername('empty');
         $user->setEnabled(false);
         $em->persist($user);
 
         $user = $em
-            ->getRepository('WallabagUserBundle:User')
+            ->getRepository(User::class)
             ->findOneByUsername('bob');
         $user->setEnabled(false);
         $em->persist($user);
@@ -798,13 +801,13 @@ class ConfigControllerTest extends WallabagCoreTestCase
         $this->assertSame(403, $client->getResponse()->getStatusCode());
 
         $user = $em
-            ->getRepository('WallabagUserBundle:User')
+            ->getRepository(User::class)
             ->findOneByUsername('empty');
         $user->setEnabled(true);
         $em->persist($user);
 
         $user = $em
-            ->getRepository('WallabagUserBundle:User')
+            ->getRepository(User::class)
             ->findOneByUsername('bob');
         $user->setEnabled(true);
         $em->persist($user);
@@ -817,8 +820,8 @@ class ConfigControllerTest extends WallabagCoreTestCase
      */
     public function testDeleteAccount()
     {
-        $client = $this->getClient();
-        $em = $client->getContainer()->get('doctrine.orm.entity_manager');
+        $client = $this->getTestClient();
+        $em = $client->getContainer()->get(EntityManagerInterface::class);
 
         $user = new User();
         $user->setName('Wallace');
@@ -830,9 +833,8 @@ class ConfigControllerTest extends WallabagCoreTestCase
 
         $em->persist($user);
 
-        $config = new Config($user);
+        $config = new ConfigEntity($user);
 
-        $config->setTheme('material');
         $config->setItemsPerPage(30);
         $config->setReadingSpeed(200);
         $config->setLanguage('en');
@@ -865,9 +867,9 @@ class ConfigControllerTest extends WallabagCoreTestCase
         $client->submit($deleteForm);
         $this->assertSame(302, $client->getResponse()->getStatusCode());
 
-        $em = $client->getContainer()->get('doctrine.orm.entity_manager');
+        $em = $client->getContainer()->get(EntityManagerInterface::class);
         $user = $em
-            ->getRepository('WallabagUserBundle:User')
+            ->getRepository(User::class)
             ->createQueryBuilder('u')
             ->where('u.username = :username')->setParameter('username', 'wallace')
             ->getQuery()
@@ -877,8 +879,8 @@ class ConfigControllerTest extends WallabagCoreTestCase
         $this->assertNull($user);
 
         $entries = $client->getContainer()
-            ->get('doctrine.orm.entity_manager')
-            ->getRepository('WallabagCoreBundle:Entry')
+            ->get(EntityManagerInterface::class)
+            ->getRepository(Entry::class)
             ->findByUser($loggedInUserId);
 
         $this->assertEmpty($entries);
@@ -887,11 +889,13 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testReset()
     {
         $this->logInAs('empty');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
-        $em = $client->getContainer()->get('doctrine.orm.entity_manager');
+        $em = $client->getContainer()->get(EntityManagerInterface::class);
 
-        $user = static::$kernel->getContainer()->get('security.token_storage')->getToken()->getUser();
+        $user = static::$kernel->getContainer()->get(TokenStorageInterface::class)->getToken()->getUser();
+
+        \assert($user instanceof User);
 
         $tag = new Tag();
         $tag->setLabel('super');
@@ -928,10 +932,10 @@ class ConfigControllerTest extends WallabagCoreTestCase
         $crawler = $client->click($crawler->selectLink('config.reset.annotations')->link());
 
         $this->assertSame(302, $client->getResponse()->getStatusCode());
-        $this->assertStringContainsString('flashes.config.notice.annotations_reset', $client->getContainer()->get('session')->getFlashBag()->get('notice')[0]);
+        $this->assertStringContainsString('flashes.config.notice.annotations_reset', $client->getContainer()->get(SessionInterface::class)->getFlashBag()->get('notice')[0]);
 
         $annotationsReset = $em
-            ->getRepository('WallabagAnnotationBundle:Annotation')
+            ->getRepository(Annotation::class)
             ->findByEntryIdAndUserId($entry->getId(), $user->getId());
 
         $this->assertEmpty($annotationsReset, 'Annotations were reset');
@@ -944,10 +948,10 @@ class ConfigControllerTest extends WallabagCoreTestCase
         $crawler = $client->click($crawler->selectLink('config.reset.tags')->link());
 
         $this->assertSame(302, $client->getResponse()->getStatusCode());
-        $this->assertStringContainsString('flashes.config.notice.tags_reset', $client->getContainer()->get('session')->getFlashBag()->get('notice')[0]);
+        $this->assertStringContainsString('flashes.config.notice.tags_reset', $client->getContainer()->get(SessionInterface::class)->getFlashBag()->get('notice')[0]);
 
         $tagReset = $em
-            ->getRepository('WallabagCoreBundle:Tag')
+            ->getRepository(Tag::class)
             ->countAllTags($user->getId());
 
         $this->assertSame(0, $tagReset, 'Tags were reset');
@@ -960,10 +964,10 @@ class ConfigControllerTest extends WallabagCoreTestCase
         $crawler = $client->click($crawler->selectLink('config.reset.entries')->link());
 
         $this->assertSame(302, $client->getResponse()->getStatusCode());
-        $this->assertStringContainsString('flashes.config.notice.entries_reset', $client->getContainer()->get('session')->getFlashBag()->get('notice')[0]);
+        $this->assertStringContainsString('flashes.config.notice.entries_reset', $client->getContainer()->get(SessionInterface::class)->getFlashBag()->get('notice')[0]);
 
         $entryReset = $em
-            ->getRepository('WallabagCoreBundle:Entry')
+            ->getRepository(Entry::class)
             ->countAllEntriesByUser($user->getId());
 
         $this->assertSame(0, $entryReset, 'Entries were reset');
@@ -972,11 +976,13 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testResetArchivedEntries()
     {
         $this->logInAs('empty');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
-        $em = $client->getContainer()->get('doctrine.orm.entity_manager');
+        $em = $client->getContainer()->get(EntityManagerInterface::class);
 
-        $user = static::$kernel->getContainer()->get('security.token_storage')->getToken()->getUser();
+        $user = static::$kernel->getContainer()->get(TokenStorageInterface::class)->getToken()->getUser();
+
+        \assert($user instanceof User);
 
         $tag = new Tag();
         $tag->setLabel('super');
@@ -1024,22 +1030,22 @@ class ConfigControllerTest extends WallabagCoreTestCase
         $crawler = $client->click($crawler->selectLink('config.reset.archived')->link());
 
         $this->assertSame(302, $client->getResponse()->getStatusCode());
-        $this->assertStringContainsString('flashes.config.notice.archived_reset', $client->getContainer()->get('session')->getFlashBag()->get('notice')[0]);
+        $this->assertStringContainsString('flashes.config.notice.archived_reset', $client->getContainer()->get(SessionInterface::class)->getFlashBag()->get('notice')[0]);
 
         $entryReset = $em
-            ->getRepository('WallabagCoreBundle:Entry')
+            ->getRepository(Entry::class)
             ->countAllEntriesByUser($user->getId());
 
         $this->assertSame(1, $entryReset, 'Entries were reset');
 
         $tagReset = $em
-            ->getRepository('WallabagCoreBundle:Tag')
+            ->getRepository(Tag::class)
             ->countAllTags($user->getId());
 
         $this->assertSame(1, $tagReset, 'Tags were reset');
 
         $annotationsReset = $em
-            ->getRepository('WallabagAnnotationBundle:Annotation')
+            ->getRepository(Annotation::class)
             ->findByEntryIdAndUserId($annotationArchived->getId(), $user->getId());
 
         $this->assertEmpty($annotationsReset, 'Annotations were reset');
@@ -1048,11 +1054,13 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testResetEntriesCascade()
     {
         $this->logInAs('empty');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
-        $em = $client->getContainer()->get('doctrine.orm.entity_manager');
+        $em = $client->getContainer()->get(EntityManagerInterface::class);
 
-        $user = static::$kernel->getContainer()->get('security.token_storage')->getToken()->getUser();
+        $user = static::$kernel->getContainer()->get(TokenStorageInterface::class)->getToken()->getUser();
+
+        \assert($user instanceof User);
 
         $tag = new Tag();
         $tag->setLabel('super');
@@ -1081,22 +1089,22 @@ class ConfigControllerTest extends WallabagCoreTestCase
         $crawler = $client->click($crawler->selectLink('config.reset.entries')->link());
 
         $this->assertSame(302, $client->getResponse()->getStatusCode());
-        $this->assertStringContainsString('flashes.config.notice.entries_reset', $client->getContainer()->get('session')->getFlashBag()->get('notice')[0]);
+        $this->assertStringContainsString('flashes.config.notice.entries_reset', $client->getContainer()->get(SessionInterface::class)->getFlashBag()->get('notice')[0]);
 
         $entryReset = $em
-            ->getRepository('WallabagCoreBundle:Entry')
+            ->getRepository(Entry::class)
             ->countAllEntriesByUser($user->getId());
 
         $this->assertSame(0, $entryReset, 'Entries were reset');
 
         $tagReset = $em
-            ->getRepository('WallabagCoreBundle:Tag')
+            ->getRepository(Tag::class)
             ->countAllTags($user->getId());
 
         $this->assertSame(0, $tagReset, 'Tags were reset');
 
         $annotationsReset = $em
-            ->getRepository('WallabagAnnotationBundle:Annotation')
+            ->getRepository(Annotation::class)
             ->findByEntryIdAndUserId($entry->getId(), $user->getId());
 
         $this->assertEmpty($annotationsReset, 'Annotations were reset');
@@ -1105,62 +1113,61 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testSwitchViewMode()
     {
         $this->logInAs('admin');
-        $this->useTheme('baggy');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $client->request('GET', '/unread/list');
 
-        $this->assertStringNotContainsString('listmode', $client->getResponse()->getContent());
+        $this->assertStringContainsString('row data', $client->getResponse()->getContent());
 
         $client->request('GET', '/config/view-mode');
         $crawler = $client->followRedirect();
 
         $client->request('GET', '/unread/list');
 
-        $this->assertStringContainsString('listmode', $client->getResponse()->getContent());
+        $this->assertStringContainsString('collection', $client->getResponse()->getContent());
 
         $client->request('GET', '/config/view-mode');
     }
 
     public function testChangeLocaleWithoutReferer()
     {
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $client->request('GET', '/locale/de');
         $client->followRedirect();
 
         $this->assertSame('de', $client->getRequest()->getLocale());
-        $this->assertSame('de', $client->getContainer()->get('session')->get('_locale'));
+        $this->assertSame('de', $client->getContainer()->get(SessionInterface::class)->get('_locale'));
     }
 
     public function testChangeLocaleWithReferer()
     {
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $client->request('GET', '/login');
         $client->request('GET', '/locale/de');
         $client->followRedirect();
 
         $this->assertSame('de', $client->getRequest()->getLocale());
-        $this->assertSame('de', $client->getContainer()->get('session')->get('_locale'));
+        $this->assertSame('de', $client->getContainer()->get(SessionInterface::class)->get('_locale'));
     }
 
     public function testChangeLocaleToBadLocale()
     {
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $client->request('GET', '/login');
         $client->request('GET', '/locale/yuyuyuyu');
         $client->followRedirect();
 
         $this->assertNotSame('yuyuyuyu', $client->getRequest()->getLocale());
-        $this->assertNotSame('yuyuyuyu', $client->getContainer()->get('session')->get('_locale'));
+        $this->assertNotSame('yuyuyuyu', $client->getContainer()->get(SessionInterface::class)->get('_locale'));
     }
 
     public function testUserEnable2faEmail()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config/otp/email');
 
@@ -1174,7 +1181,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
         // restore user
         $em = $this->getEntityManager();
         $user = $em
-            ->getRepository('WallabagUserBundle:User')
+            ->getRepository(User::class)
             ->findOneByUsername('admin');
 
         $this->assertTrue($user->isEmailTwoFactor());
@@ -1187,7 +1194,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testUserDisable2faEmail()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config/otp/email/disable');
 
@@ -1201,7 +1208,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
         // restore user
         $em = $this->getEntityManager();
         $user = $em
-            ->getRepository('WallabagUserBundle:User')
+            ->getRepository(User::class)
             ->findOneByUsername('admin');
 
         $this->assertFalse($user->isEmailTwoFactor());
@@ -1210,7 +1217,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testUserEnable2faGoogle()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config/otp/app');
 
@@ -1219,7 +1226,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
         // restore user
         $em = $this->getEntityManager();
         $user = $em
-            ->getRepository('WallabagUserBundle:User')
+            ->getRepository(User::class)
             ->findOneByUsername('admin');
 
         $this->assertTrue($user->isGoogleTwoFactor());
@@ -1234,7 +1241,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testUserEnable2faGoogleCancel()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config/otp/app');
 
@@ -1243,7 +1250,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
         // restore user
         $em = $this->getEntityManager();
         $user = $em
-            ->getRepository('WallabagUserBundle:User')
+            ->getRepository(User::class)
             ->findOneByUsername('admin');
 
         $this->assertTrue($user->isGoogleTwoFactor());
@@ -1254,7 +1261,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
         $this->assertSame(302, $client->getResponse()->getStatusCode());
 
         $user = $em
-            ->getRepository('WallabagUserBundle:User')
+            ->getRepository(User::class)
             ->findOneByUsername('admin');
 
         $this->assertFalse($user->isGoogleTwoFactor());
@@ -1264,7 +1271,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testUserDisable2faGoogle()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config/otp/app/disable');
 
@@ -1278,7 +1285,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
         // restore user
         $em = $this->getEntityManager();
         $user = $em
-            ->getRepository('WallabagUserBundle:User')
+            ->getRepository(User::class)
             ->findOneByUsername('admin');
 
         $this->assertEmpty($user->getGoogleAuthenticatorSecret());
@@ -1288,7 +1295,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testExportTaggingRule()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         ob_start();
         $crawler = $client->request('GET', '/tagging-rule/export');
@@ -1311,7 +1318,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testImportTagginfRuleBadFile()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
         $form = $crawler->filter('form[name=upload_tagging_rule_file] > button[type=submit]')->form();
@@ -1328,7 +1335,7 @@ class ConfigControllerTest extends WallabagCoreTestCase
     public function testImportTagginfRuleFile()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/config');
         $form = $crawler->filter('form[name=upload_tagging_rule_file] > button[type=submit]')->form();
@@ -1347,4 +1354,40 @@ class ConfigControllerTest extends WallabagCoreTestCase
         $this->assertCount(5, $taggingRules);
         $this->assertSame('title matches "football"', $taggingRules[4]->getRule());
     }
+
+    public function testSwitchDisplayThumbnails()
+    {
+        $this->logInAs('admin');
+        $client = $this->getTestClient();
+
+        // Change configuration to show thumbnails
+        $crawler = $client->request('GET', '/config');
+        $this->assertSame(200, $client->getResponse()->getStatusCode());
+        $form = $crawler->filter('button[id=config_save]')->form();
+        $data = [
+            'config[display_thumbnails]' => true,
+        ];
+        $client->submit($form, $data);
+        $client->followRedirect();
+
+        $client->request('GET', '/unread/list');
+
+        $this->assertStringContainsString('class="preview"', $client->getResponse()->getContent());
+
+        // Change configuration to hide thumbnails
+        $crawler = $client->request('GET', '/config');
+        $this->assertSame(200, $client->getResponse()->getStatusCode());
+        $form = $crawler->filter('button[id=config_save]')->form();
+        $data = [
+            'config[display_thumbnails]' => false,
+        ];
+        $client->submit($form, $data);
+        $client->followRedirect();
+
+        $client->request('GET', '/unread/list');
+
+        $this->assertStringNotContainsString('class="preview"', $client->getResponse()->getContent());
+
+        $client->request('GET', '/config/view-mode');
+    }
 }
